{% extends "base.html" %}

{% block content %}
{% if page.nb_url %}
    <a href="{{ page.nb_url }}" title="Download Notebook" class="md-content__button md-icon">
        {% include ".icons/material/download.svg" %}
    </a>
    <a href="{{ config.extra.colab_base_url }}{{ page.nb_url }}"
       title="Open Notebook in Google Colab" class="md-content__button md-icon">
        {% include ".icons/material/play-circle-outline.svg" %}
    </a>
{% endif %}
{{ super() }}
{% endblock content %}
